@@ -1,9 +1,9 @@
 /*
- * $Id: bulletin_gui.h,v 1.4 2001/05/01 14:33:43 kg4ijb Exp $
+ * $Id: bulletin_gui.h,v 1.7 2003/02/26 01:55:04 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000,2001  The Xastir Group
+ * Copyright (C) 2000-2003  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,10 +27,12 @@
 
 extern int bulletin_range;
 
-/* from bulletin.c */
-extern void bulletin_message(char from, char *call_sign, char *tag, char *packet_message, time_t sec_heard);
 
 // From bulletin_gui.c
 extern void bulletin_gui_init(void);
+extern void bulletin_data_add(char *call_sign, char *from_call, char *data, char *seq, char type, char from);
+extern void check_for_new_bulletins(void);
+
+#endif  // __XASTIR_BULLETIN_GUI_H
+
 
-#endif
