@@ -1,9 +1,9 @@
-/*
- * $Id: color.h,v 1.5 2001/05/01 14:33:43 kg4ijb Exp $
+/* -*- c-basic-indent: 4; indent-tabs-mode: nil -*-
+ * $Id: color.h,v 1.3 2003/01/24 00:37:40 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000,2001  The Xastir Group
+ * Copyright (C) 2000-2003  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -25,17 +25,27 @@
 #ifndef XASTIR_COLOR_H
 #define XASTIR_COLOR_H
 
-#define MAX_COLORS 70
+#define MAX_COLORS 75
 
 typedef struct {
     char colorname[40];
     XColor color;
 } color_load;
 
+typedef enum {
+    NOT_TRUE_NOR_DIRECT,
+    RGB_565,
+    RGB_555,
+    RGB_888,
+    RGB_OTHER
+} Pixel_Format;
+extern Pixel_Format visual_type;
+
 /* from color.c */
 extern int load_color_file(void);
 extern Pixel GetPixelByName(Widget w, char *colorname);
-
+extern void setup_visual_info(Display* dpy, int scr);
+extern void pack_pixel_bits(unsigned short r, unsigned short g, unsigned short b, unsigned long* pixel);
 
 #endif /* XASTIR_COLOR_H */
 
