@@ -1,9 +1,9 @@
 /*
- * $Id: fcc_data.c,v 1.11 2001/05/01 14:33:43 kg4ijb Exp $
+ * $Id: fcc_data.c,v 1.5 2003/05/20 17:34:10 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000,2001  The Xastir Group
+ * Copyright (C) 2000-2003  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,15 +22,24 @@
  * Look at the README for more information on the program.
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
+#include "snprintf.h"
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
-#include <sys/time.h>
+
+#if TIME_WITH_SYS_TIME
+# include <sys/time.h>
+# include <time.h>
+#else   // TIME_WITH_SYS_TIME
+# if HAVE_SYS_TIME_H
+#  include <sys/time.h>
+# else  // HAVE_SYS_TIME_H
+#  include <time.h>
+# endif // HAVE_SYS_TIME_H
+#endif  // TIME_WITH_SYS_TIME
 
 #include <Xm/XmAll.h>
 
@@ -39,7 +48,8 @@
 #include "main.h"
 #include "xastir.h"
 
-int fcc_data_available;
+
+
 
 
 char *call_only(char *callsign) {
@@ -55,6 +65,9 @@ char *call_only(char *callsign) {
 }
 
 
+
+
+
 /* ====================================================================    */
 /*    build a new (or newer if I check the file date) index file    */
 /*    check for current ic index file                    */
@@ -62,6 +75,9 @@ char *call_only(char *callsign) {
 /*      appl.dat must have a time stamp newer than the index file time  */
 /*      stamp. Use the touch command on the appl.dat file to make the   */
 /*      time current if necessary.                                      */
+//    How this works:  The index file contains a few callsigns and their
+//    offsets into the large database file.  The code uses these as
+//    jump-off points to look for a particular call, to speed things up.
 /* ******************************************************************** */
 int build_fcc_index(int type){
     FILE *fdb;
@@ -97,13 +113,13 @@ int build_fcc_index(int type){
     /*                                    */
     fdb=fopen(get_data_base_dir(database_name),"rb");
     if (fdb==NULL){
-        printf("Build:Could not open FCC data base: %s\n", get_data_base_dir(database_name) );
+        fprintf(stderr,"Build:Could not open FCC data base: %s\n", get_data_base_dir(database_name) );
         return(0);
     }
 
     fndx=fopen(get_user_base_dir("data/appl.ndx"),"w");
     if (fndx==NULL){
-        printf("Build:Could not open/create FCC data base index: %s\n", get_user_base_dir("data/appl.ndx") );
+        fprintf(stderr,"Build:Could not open/create FCC data base index: %s\n", get_user_base_dir("data/appl.ndx") );
         (void)fclose(fdb);
         return(0);
     }
@@ -143,46 +159,50 @@ int build_fcc_index(int type){
 }
 
 
+
+
+
 /* ====================================================================    */
 /*    Check for ic data base file                    */
 /*    Check/build the index                        */
 /*                                    */
 /* ******************************************************************** */
 int check_fcc_data(void) {
+    int fcc_data_available = 0;
     if (filethere(get_data_base_dir("fcc/EN.dat")) && filethere(get_data_base_dir("fcc/appl.dat"))) {
         if(file_time(get_data_base_dir("fcc/appl.dat"))<=file_time(get_data_base_dir("fcc/EN.dat"))) {
-            /*printf("NEW FORMAT FCC DATA FILE is NEWER THAN OLD FCC FORMAT\n");*/
+            /*fprintf(stderr,"NEW FORMAT FCC DATA FILE is NEWER THAN OLD FCC FORMAT\n");*/
             if (build_fcc_index(2))
                 fcc_data_available=2;
             else {
-                printf("Check:Could not build fcc data base index\n");
+                fprintf(stderr,"Check:Could not build fcc data base index\n");
                 fcc_data_available=0;
             }
         } else {
-            /*printf("OLD FORMAT FCC DATA FILE is NEWER THAN NEW FCC FORMAT\n");*/
+            /*fprintf(stderr,"OLD FORMAT FCC DATA FILE is NEWER THAN NEW FCC FORMAT\n");*/
             if (build_fcc_index(1))
                 fcc_data_available=1;
             else {
-                printf("Check:Could not build fcc data base index\n");
+                fprintf(stderr,"Check:Could not build fcc data base index\n");
                 fcc_data_available=0;
             }
         }
     } else {
         if (filethere(get_data_base_dir("fcc/EN.dat"))) {
-            /*printf("NO OLD FCC, BUT NEW FORMAT FCC DATA AVIALABLE\n");*/
+            /*fprintf(stderr,"NO OLD FCC, BUT NEW FORMAT FCC DATA AVAILABLE\n");*/
             if (build_fcc_index(2))
                 fcc_data_available=2;
             else {
-                printf("Check:Could not build fcc data base index\n");
+                fprintf(stderr,"Check:Could not build fcc data base index\n");
                 fcc_data_available=0;
             }
         } else {
             if (filethere(get_data_base_dir("fcc/appl.dat"))) {
-                /*printf("NO NEW FCC, BUT OLD FORMAT FCC DATA AVIALABLE\n");*/
+                /*fprintf(stderr,"NO NEW FCC, BUT OLD FORMAT FCC DATA AVAILABLE\n");*/
                 if (build_fcc_index(1))
                     fcc_data_available=1;
                 else {
-                    printf("Check:Could not build fcc data base index\n");
+                    fprintf(stderr,"Check:Could not build fcc data base index\n");
                     fcc_data_available=0;
                 }
             }
@@ -191,6 +211,10 @@ int check_fcc_data(void) {
     return(fcc_data_available);
 }
 
+
+
+
+
 int search_fcc_data_appl(char *callsign, FccAppl *data) {
     FILE *f;
     char line[200];
@@ -226,7 +250,10 @@ int search_fcc_data_appl(char *callsign, FccAppl *data) {
     data->renewal_notice=' ';
     strcpy(temp,callsign);
     (void)call_only(temp);
-    sprintf(calltemp,"%-6.6s",temp);
+
+    xastir_snprintf(calltemp, sizeof(calltemp), "%-6.6s", temp);
+// calltemp doesn't appear to get used anywhere...
+
     /* add end of field data */
     strcat(temp,"|");
     len=(int)strlen(temp);
@@ -239,28 +266,36 @@ int search_fcc_data_appl(char *callsign, FccAppl *data) {
     if (! (callsign[0] == 'A' || callsign[0] == 'K' || callsign[0] == 'N' || callsign[0] == 'W') )
         return(0);  // Not found
 
-    /* ====================================================================    */
-    /*    Search thru the index, get the RBA                */
-    /*                                    */
+    // ====================================================================
+    // Search thru the index, get the RBA 
+    // 
+    // This gives us a jumping-off point to start looking in the right
+    // neighborhood for the callsign of interest.
+    //
     fndx=fopen(get_user_base_dir("data/appl.ndx"),"r");
     if (fndx!=NULL){
         (void)fgets(index,(int)sizeof(index),fndx);
         strncpy(char_offset,&index[6],16);
 
+        // Search through the indexes looking for a callsign which is
+        // close to the callsign of interest.  If callsign is later in
+        // the alphabet than the current index, snag the next index.
         while (!feof(fndx) && strncmp(callsign,index,6) > 0) {
             strncpy(char_offset,&index[6],16);
             (void)fgets(index,(int)sizeof(index),fndx);
         }
     } else {
-        printf("Search:Could not open FCC data base index: %s\n", get_user_base_dir("data/appl.ndx") );
+        fprintf(stderr,"Search:Could not open FCC data base index: %s\n", get_user_base_dir("data/appl.ndx") );
         return (0);
     }
     call_offset = atol(char_offset);
+
     (void)fclose(fndx);
 
     /* ====================================================================    */
     /*    Continue with the original search                */
     /*                                                                */
+
     f=NULL;
     switch (which) {
         case(1):
@@ -287,7 +322,7 @@ int search_fcc_data_appl(char *callsign, FccAppl *data) {
                         }
                     } else {
                         line_pos=0;
-                        /*printf("line:%s\n",line);*/
+                        /*fprintf(stderr,"line:%s\n",line);*/
                         pos=0;
                         num=0;
                         if (which==2) {
@@ -301,7 +336,7 @@ int search_fcc_data_appl(char *callsign, FccAppl *data) {
                         }
                         if (strncmp(line+pos,temp,(size_t)len)==0) {
                             found=1;
-                            /*printf("line:%s\n",line);*/
+                            /*fprintf(stderr,"line:%s\n",line);*/
                             llen=(int)strlen(line);
                             /* replace "|" with 0 */
                             for (ii=pos;ii<llen;ii++) {
@@ -318,7 +353,7 @@ int search_fcc_data_appl(char *callsign, FccAppl *data) {
                                 }
                                 pos_it++;
                                 if (line[pos_it]!='\0') {
-                                    /*printf("DATA %d %d:%s\n",i,pos_it,line+pos_it);*/
+                                    /*fprintf(stderr,"DATA %d %d:%s\n",i,pos_it,line+pos_it);*/
                                     switch (which) {
                                         case(1):
                                             switch(i) {
@@ -420,14 +455,26 @@ int search_fcc_data_appl(char *callsign, FccAppl *data) {
                                 }
                             }
                         }
+                        else {
+                            // Check whether we passed the alphabetic
+                            // location for the callsign.  Return if so.
+                            if ( (temp[0] < line[pos]) ||
+                                    ( (temp[0] == line[pos]) && (temp[1] < line[pos+1]) ) ) {
+                                popup_message("Callsign Search", "Callsign Not Found!");
+                                //fprintf(stderr,"%c%c\t%c%c\n",temp[0],temp[1],line[pos],line[pos+1]);
+                                (void)fclose(f);
+                                return(0);
+                            }
+                        }
                     }
                 }
             }
         }
         (void)fclose(f);
-    } else
-        printf("Could not open FCC appl data base at: %s\n", get_data_base_dir("fcc/") );
-
+    } else {
+        fprintf(stderr,"Could not open FCC appl data base at: %s\n", get_data_base_dir("fcc/") );
+    }
     return(found);
 }
 
+
