@@ -1,6 +1,6 @@
 // Modification for Xastir CVS purposes
 //
-// $Id: festival.c,v 1.5 2001/04/10 22:00:14 we7u Exp $
+// $Id: festival.c,v 1.9 2003/04/12 01:32:42 we7u Exp $
 //
 // End of modification
 
@@ -89,133 +89,266 @@
 #include "festival.h"
 #include <errno.h>
 #include "xastir.h"
+#include "snprintf.h"
 
-FT_Info *info;      
+FT_Info *info = NULL;
+
+static char last_speech_text[8000];
+static time_t last_speech_time = (time_t)0;
+static time_t festival_connect_attempt_time = (time_t)0;
 
 
 
-void festival_default_info()
-{
-    info = (FT_Info *)malloc(1 * sizeof(FT_Info));
-    info->server_host = FESTIVAL_DEFAULT_SERVER_HOST;
-    info->server_port = FESTIVAL_DEFAULT_SERVER_PORT;
-    info->text_mode = FESTIVAL_DEFAULT_TEXT_MODE;
-    info->server_fd = -1;
-    
-    return ;
+
+
+// Set up default struct
+//
+void festival_default_info(void) {
+
+    if (info == NULL) { // First time through
+
+        // Malloc storage for the struct
+        info = (FT_Info *)malloc(1 * sizeof(FT_Info));
+
+        // Fill in the struct
+        if (info != NULL) {
+            info->server_host = FESTIVAL_DEFAULT_SERVER_HOST;
+            info->server_port = FESTIVAL_DEFAULT_SERVER_PORT;
+            info->text_mode = FESTIVAL_DEFAULT_TEXT_MODE;
+            info->server_fd = -1;
+        }
+        else {  // Couldn't allocate memory
+            fprintf(stderr,"festival_default_info: Couldn't malloc\n");
+        }
+    }
+
+    return;
 }
 
 
 
-static int festival_socket_open(const char *host, int port)
-{   
-    /* Return an FD to a remote server */
+
+
+// Returns a FD to a remote server
+//
+static int festival_socket_open(const char *host, int port) {
     struct sockaddr_in serv_addr;
     struct hostent *serverhost;
     int fd;
 
-    fd = socket(AF_INET, SOCK_STREAM, IPPROTO_TCP);
 
-    if (fd < 0)  
-    {
-    fprintf(stderr,"festival_client: can't get socket\n");
-    return -1;
+    // Delay at least 60 seconds between each socket attempt
+    if ( (festival_connect_attempt_time + 60) > sec_now() ) {
+        //fprintf(stderr,"Not time yet\n");
+        return(-1);
     }
+    festival_connect_attempt_time = sec_now();
+
+    if ((fd = socket(PF_INET, SOCK_STREAM, IPPROTO_TCP)) < 0) {
+        fprintf(stderr,"festival_client: can't get socket\n");
+        return(-1);
+    }
+
     memset(&serv_addr, 0, sizeof(serv_addr));
-    if ((serv_addr.sin_addr.s_addr = inet_addr(host)) == -1)
-    {
-    /* its a name rather than an ipnum */
-    serverhost = gethostbyname(host);
-    if (serverhost == (struct hostent *)0)
-    {
-        fprintf(stderr,"festival_client: gethostbyname failed\n");
-        return -1;
-    }
-    memmove(&serv_addr.sin_addr,serverhost->h_addr, (size_t)serverhost->h_length);
+
+    if ((int)(serv_addr.sin_addr.s_addr = inet_addr(host)) == -1) {
+        /* its a name rather than an ipnum */
+        serverhost = gethostbyname(host);
+        if (serverhost == (struct hostent *)0) {
+            fprintf(stderr,"festival_client: gethostbyname failed\n");
+            return(-1);
+        }
+        memmove(&serv_addr.sin_addr,serverhost->h_addr, (size_t)serverhost->h_length);
     }
     serv_addr.sin_family = AF_INET;
     serv_addr.sin_port = htons(port);
 
-    if (connect(fd, (struct sockaddr *)&serv_addr, sizeof(serv_addr)) != 0)
-    {
-    fprintf(stderr,"festival_client: connect to server failed\n");
-    return -1;
+    if (connect(fd, (struct sockaddr *)&serv_addr, sizeof(serv_addr)) != 0) {
+        fprintf(stderr,"festival_client: connect to server failed\n");
+        return(-1);
     }
-    return fd;
+    return(fd);
 }
 
 
 
+
+
 /***********************************************************************/
 /* Public Functions to this API                                        */
 /***********************************************************************/
 
-void festivalOpen()
-{
-    /* Open socket to server */
 
-    if (info == 0)
-    festival_default_info();
 
-    info->server_fd = 
-    festival_socket_open(info->server_host, info->server_port);
-    if (info->server_fd == -1)
-    return;
+// Close socket to server
+//
+int festivalClose(void) {
 
-    return;
+    //fprintf(stderr,"festivalClose()\n");
+
+    if (info != NULL) {    // We have a struct allocated
+
+        // Check whether we have a socket open
+        if (info->server_fd != -1) {
+            fprintf(stderr,"Closing Festival socket\n");
+            (void)close(info->server_fd);   // Close the socket
+            info->server_fd = -1;   // Just to be safe
+        }
+
+        // Free the struct, zero the pointer.  The struct will get
+        // re-created/re-initialized later when we re-open the
+        // festival connection.
+        free(info);
+        info = NULL;
+    }
+
+    return(0);
 }
 
 
-void festivalStringToSpeech(char *text)
-{
+
+
+
+// Open socket to server.  Close the connection if one is already
+// open.
+//
+int festivalOpen(void) {
+
+
+    //fprintf(stderr,"festivalOpen()\n");
+
+    festival_default_info();
+
+    // Check whether we have a record to work with
+    if (info == NULL) {
+        return(-1);
+    }
+
+    // Check whether we already have a socket open (or think we do)
+    if (info->server_fd != -1) {    // We have a socket open
+        (void)festivalClose();      // Close it, free struct
+    }
+
+    info->server_fd = festival_socket_open(info->server_host, info->server_port);
+
+    if (info->server_fd == -1) {    // Error occured opening socket
+        //fprintf(stderr,"festivalOpen: Error opening socket\n");
+        (void)festivalClose();      // Close, free struct
+        return(-1);
+    }
+
+    return(0);
+}
+
+
+
+
+
+void festivalStringToSpeech(char *text) {
     FILE *fd;
     char *p;
     char ack[4];
     int n;
     int tmp = 0;
+    int ret;
 
-    if (info == 0)
-    return;
 
-    if (info->server_fd == -1)
-    {
-    fprintf(stderr,"festival_client: server connection unopened\n");
-    return;
+    //fprintf(stderr,"festivalStringToSpeech()\n");
+
+    // If we don't have a struct allocated
+    if (info == 0) {
+        if (festivalOpen() == -1) { // Allocate struct, open socket
+            //fprintf(stderr,"festivalStringToSpeech: Couldn't open socket to Festival\n");
+            return;
+        }
     }
+
+    if (info == 0) {    // If socket is still not open
+        return;
+    }
+
+    if (info->server_fd == -1) {
+        fprintf(stderr,"festival_client: server connection unopened\n");
+        (void)festivalClose();
+        return;
+    }
+
     fd = fdopen(dup(info->server_fd),"wb");
+
+    if (fd == NULL) {
+        fprintf(stderr,"Couldn't create duplicate socket\n");
+        (void)festivalClose();
+        return;
+    }
+
     /*
     **  Send the mode commands to festival
     */
-    fprintf(fd,"(audio_mode `async)\n(SayText \"\n");
+    ret = fprintf(fd,"(audio_mode `async)\n(SayText \"\n");
+
+    if (ret == 0 || ret == -1) {
+        fprintf(stderr,"Couldn't send mode commands to festival\n");
+        (void)fclose(fd);
+        (void)festivalClose();
+        return;
+    }
+
     /* 
     **  Copy text over to server, escaping any quotes 
     */ 
-    for (p=text; p && (*p != '\0'); p++)
-      {
-    	if ((*p == '"') || (*p == '\\'))
-	  {
-	    (void)putc('\\',fd);
-	  } else {
-	    /* 
-	    ** Then convert any embedded '-' into the word 'dash'
-	    ** This could cause problems with spoken text from 
-	    ** Weather alerts or messages.  We'll deal with that 
-	    ** later if necessary.  Making this a seperate function
+    for (p=text; p && (*p != '\0'); p++) {
+        if ((*p == '"') || (*p == '\\')) {
+
+            if (putc('\\',fd) == EOF) { // Error writing to socket
+                fprintf(stderr,"Error writing to socket\n");
+                (void)fclose(fd);
+                (void)festivalClose();
+                return;
+            }
+        }
+        else {
+            /* 
+            ** Then convert any embedded '-' into the word 'dash'
+            ** This could cause problems with spoken text from 
+            ** Weather alerts or messages.  We'll deal with that 
+            ** later if necessary.  Making this a separate function
             ** is probably the thing to do.
-	    */
-	    if (*p == '-' ) 
-	      {
-		fprintf(fd,",dash,");
-	      } else {
-		(void)putc(*p,fd);
-	      }
-	  }
-      }	
+            */
+            if (*p == '-' ) {
+
+                ret = fprintf(fd,",dash,");
+
+                if (ret == 0 || ret == -1) {
+                    fprintf(stderr,"Error writing to socket\n");
+                    (void)fclose(fd);
+                    (void)festivalClose();
+                    return;
+                }
+            }
+            else {
+
+                if (putc(*p,fd) == EOF) {   // Error writing to socket
+                    fprintf(stderr,"Error writing to socket\n");
+                    (void)fclose(fd);
+                    (void)festivalClose();
+                    return;
+                }
+            }
+        }
+    } 
     /*
     ** Complete the command to xastir, close the quotes and 
     ** set the mode to 'fundamental'
     */
-    fprintf(fd,"\" \"%s\")\n",info->text_mode);
+    ret = fprintf(fd,"\" \"%s\")\n",info->text_mode);
+
+    if (ret == 0 || ret == -1) {
+        fprintf(stderr,"Error writing to socket\n");
+        (void)fclose(fd);
+        (void)festivalClose();
+        return;
+    }
+
     /*
     ** Close the duplicate port we used for writing
     */
@@ -234,56 +367,87 @@ void festivalStringToSpeech(char *text)
     ** appear to matter but should be checked into. 
     */
     for (n=0; n < 3; ) {
-      if ( ( tmp = read(info->server_fd,ack+n,3-n)) != -1 ) {
-	n = n + tmp;
-      } else {
-        if (debug_level & 2)    
-	    fprintf(stderr,"Error reading festival ACK - %s\n",strerror(errno));
-	n = 3;
-	if (errno == ECONNRESET) {
-	  info = 0;
-	  festivalOpen();
-	} 
-      }
+        if ( ( tmp = read(info->server_fd,ack+n,3-n)) != -1 ) {
+            n = n + tmp;
+        }
+        else {
+            if (debug_level & 2) {
+                fprintf(stderr,"Error reading festival ACK - %s\n",strerror(errno));
+            }
+            n = 3;
+            if (errno == ECONNRESET) {
+
+                fprintf(stderr,"Connection reset\n");
+                info = 0;
+
+                (void)festivalClose();
+
+                if (festivalOpen() == -1) {
+                    fprintf(stderr,"festivalStringToSpeech2: Couldn't open socket to Festival\n");
+                    return;
+                }
+ 
+            } 
+        }
     }
-	
+        
     /*
     ** Null terminate the string
     */
     ack[3] = '\0';
     if (strcmp(ack,"ER\n") == 0) {    /* server got an error */
-      fprintf(stderr,"festival_client: server returned error\n");
+        fprintf(stderr,"festival_client: server returned error\n");
     }
     return;
 }
 
 
 
-int festivalClose()
-{
-    if (info == 0)
-    return 0;
-
-    if (info->server_fd != -1)
-    (void)close(info->server_fd);
-
-    return 0;
-}
 
 
+int SayText(char *text) {
+
+    if (debug_level & 2)
+        fprintf(stderr,"SayText: %s\n",text);
+
+    // Check whether the last text was the same and it hasn't been
+    // enough time between them (30 seconds).
+    if ( (strcmp(last_speech_text,text) == 0) // Strings match
+            && (last_speech_time + 30 > sec_now()) ) {
+
+    //fprintf(stderr,"Same text, skipping speech: %d seconds, %s\n",
+    //    (int)(sec_now() - last_speech_time),
+    //    text);
+
+        return(1);
+    }
+
+    //fprintf(stderr,"Speaking: %s\n",text);
+
+    xastir_snprintf(last_speech_text,
+        sizeof(last_speech_text),
+        "%s",
+        text);
+    last_speech_time = sec_now();
 
-int SayText(char *text)
-{
     festivalStringToSpeech(text);
-    return 0;
+    return(0);
 }
 
 
 
-int SayTextInit()
-{
-       festival_default_info();
-       festivalOpen();
-        return 0;
+
+
+int SayTextInit(void) {
+
+    if (festivalOpen() == -1) {
+        fprintf(stderr,"SayText: Couldn't open socket to Festival\n");
+    }
+ 
+    last_speech_text[0] = '\0';
+    last_speech_time = (time_t)0;
+
+    return(0);
 }
 
+
