@@ -1,9 +1,9 @@
 /*
- * $Id: gps.h,v 1.3 2001/05/01 14:33:43 kg4ijb Exp $
+ * $Id: gps.h,v 1.5 2003/03/18 22:28:05 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000,2001  The Xastir Group
+ * Copyright (C) 2000-2003  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -30,7 +30,10 @@
 
 extern int gps_stop_now;
 
-extern void gps_data_find(char *gps_line_data, int port);
+extern int gps_data_find(char *gps_line_data, int port);
+
+extern void create_garmin_waypoint(long latitude,long longitude,char *call_sign);
+
+#endif  // __XASTIR_GPS_H
 
-#endif
 
