@@ -1,9 +1,9 @@
 /*
- * $Id: hostname.c,v 1.10 2001/05/01 14:33:43 kg4ijb Exp $
+ * $Id: hostname.c,v 1.8 2003/03/20 22:29:19 jtwilley Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000,2001  The Xastir Group
+ * Copyright (C) 2000-2003  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,9 +22,8 @@
  * Look at the README for more information on the program.
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
+#include "snprintf.h"
 
 #include <Xm/XmAll.h>
 
@@ -33,6 +32,10 @@
 #include <unistd.h>
 #include <netdb.h>
 #include <signal.h>
+
+//Needed for Solaris 2.5
+#include <netinet/in.h>
+
 #include <arpa/inet.h>
 #include <sys/socket.h>
 #include <setjmp.h>
@@ -45,10 +48,17 @@
 
 
 #ifndef __LCLINT__
-static  sigjmp_buf ret_place;       /* Jump address if alarm */
+  #ifndef sigjmp_buf
+    jmp_buf ret_place;
+  #else // sigjmp_buf
+    static  sigjmp_buf ret_place;       /* Jump address if alarm */
+  #endif    // sigjmp_buf
 #endif // __LCLINT__
 
 
+
+
+
 /*************************************************************************/
 /* Time out on connect                                                   */
 /* In case there is a problem in getting the hostname or connecting      */
@@ -62,6 +72,9 @@ static void host_time_out( /*@unused@*/ int sig) {
 }
 
 
+
+
+
 /*************************************************************************/
 /* do a nice host lookup (don't thread!!)                                */
 /*                                                                       */
@@ -73,14 +86,20 @@ static void host_time_out( /*@unused@*/ int sig) {
 /* or these strings:                                                     */
 /* NOHOST  for no host by that name found                                */
 /* NOIP    for host found but no ip address available                    */
-/* TIMEOUT for time execeded                                             */
+/* TIMEOUT for time exceeded                                             */
 /*************************************************************************/
 
 char *host_lookup(char *host, char *ip, int time) {
     /*struct sockaddr_in address;*/
     char **names, **addrs;
     static struct hostent *hostinfo;
-    void *previous_loc;
+
+#ifdef RETSIGTYPE
+    RETSIGTYPE * previous_loc;
+#else 
+#error RETSIGTYPE not defined
+#endif
+
     pid_t host_pid;
     int status;
     char ip_addr[400];
@@ -95,39 +114,74 @@ char *host_lookup(char *host, char *ip, int time) {
     char ttemp[60];
     int wait_host;
 
-    if (debug_level & 256)
-        printf("Start Host lookup\n");
+    if (debug_level & 1024)
+        fprintf(stderr,"Start Host lookup\n");
 
     memset(ip_addr,(int)'\0',sizeof(ip_addr));
     memset(buf,(int)'\0',sizeof(buf));
 
     busy_cursor(appshell);
 
-    if (pipe(fp)==0) {
-        host_pid = fork();
+    if (debug_level & 1024)
+        fprintf(stderr,"Creating pipe\n");
 
-        if (debug_level & 256)
-            printf("Host fork\n");
+    if (pipe(fp)==0) {          // Create a pipe for communication
 
-        if (host_pid!=-1) {
-            if (host_pid==0) {
-                if (debug_level & 256)
-                    printf("Set alarm \n");
+        host_pid = fork();      // Fork off a child process
+
+        if (debug_level & 1024)
+            fprintf(stderr,"Host fork\n");
+
+        if (host_pid!=-1) {     // If the fork was successful
+
+//---------------------------------------------------------------------------------------
+            if (host_pid==0) {  // We're in the child process
+
+                // Close the end of the pipe we don't need here
+
+                if (debug_level & 1024)
+                    fprintf(stderr,"Child closing read end of pipe\n");
+
+                close(fp[0]);   // Read end of the pipe
+
+                if (debug_level & 1024)
+                    fprintf(stderr,"Set alarm \n");
 
                 previous_loc = signal(SIGALRM, host_time_out);
 
+                // Set up to jump here if we time out on SIGALRM
                 if (sigsetjmp(ret_place,-1)!=0) {
+
+                    // Turn off the alarm
                     (void)alarm(0);
+
+                    // Reset the SIGALRM handler to its previous value
                     (void)signal(SIGALRM, previous_loc);
-                    /* return  net connection time out */
-                    (void)write(fp[1],"TIMEOUT",sizeof(buf)-1);
+
+                    // Return net connection time out
+                    strcpy(ip_addr,"TIMEOUT");
+                    (void)write(fp[1],ip_addr,strlen(ip_addr));
+
+                    if (debug_level & 1024)
+                        fprintf(stderr,"Child closing write end of pipe\n");
+
+                    close(fp[1]);   // All done writing to the pipe
                     exit(EXIT_FAILURE);
                 }
-                (void)alarm(time);
+                (void)alarm(time);  // Start the timer
 
+                // Make the call that may time out if no response from DNS
                 /*hostinfo = gethostbyname2(host,AF_INET); some systems don't have this*/
                 hostinfo = gethostbyname(host);
 
+                // If we get to here, we haven't timed out
+                // and we have an answer to process.
+
+                // Turn off the alarm
+                (void)alarm(0);
+                // Reset the SIGALRM handler to its previous value
+                (void)signal(SIGALRM,previous_loc);
+
                 if (hostinfo) {
                     names = hostinfo -> h_aliases;
                     ip_found=0;
@@ -143,9 +197,11 @@ char *host_lookup(char *host, char *ip, int time) {
                             ip_found=1;
                             addrs = hostinfo -> h_addr_list;
                             while (*addrs) {
-                                sprintf(temp,"%s",inet_ntoa(*(struct in_addr *)*addrs));
-                                if (debug_level & 256)
-                                    printf("IP [%s]\n",temp);
+                                xastir_snprintf(temp, sizeof(temp), "%s",
+                                        inet_ntoa(*(struct in_addr *)*addrs));
+
+                                if (debug_level & 1024)
+                                    fprintf(stderr,"IP [%s]\n",temp);
 
                                 if (strlen(temp)>7) {
                                     /* IP found */
@@ -170,50 +226,78 @@ char *host_lookup(char *host, char *ip, int time) {
                         /* Host not found */
                         strcpy(ip_addr,"NOIP");
 
-                        if (debug_level & 256)
-                            printf("Host NO IP");
+                        if (debug_level & 1024)
+                            fprintf(stderr,"Host NO IP");
 
                     }
-                } else {
+                }
+                else {
                     /* Host not found */
                     strcpy(ip_addr,"NOHOST");
 
-                    if (debug_level & 256)
-                        printf("NO HOST\n");
+                    if (debug_level & 1024)
+                        fprintf(stderr,"NO HOST\n");
 
                 }
-                if (debug_level & 256)
-                    printf("Clear alarm 1\n");
+                if (debug_level & 1024)
+                    fprintf(stderr,"Clear alarm 1\n");
 
-                (void)alarm(0);
-                (void)signal(SIGALRM,previous_loc);
+                if (debug_level & 1024)
+                    fprintf(stderr,"Clear alarm 2\n");
 
-                if (debug_level & 256)
-                    printf("Clear alarm 2\n");
+                (void)write(fp[1],ip_addr,strlen(ip_addr));
 
-                (void)write(fp[1],ip_addr,sizeof(buf)-1);
+                if (debug_level & 1024)
+                    fprintf(stderr,"Child closing write end of pipe\n");
+
+                close(fp[1]);   // All done writing to the pipe
                 exit(EXIT_FAILURE);
-            } else {
-                /* parent */
+
+            }   // End of child process
+//---------------------------------------------------------------------------------------
+            else {
+                // We're in the parent process at this point
+
+                // Close the end of the pipe we don't need here
+
+                if (debug_level & 1024)
+                    fprintf(stderr,"Parent closing write end of pipe\n");
+
+                close(fp[1]);   // Write end of the pipe
+
                 tm=1;
                 wait_host=1;
                 while (wait_host!=-1) {
-                    sprintf(ttemp,langcode("BBARSTA031"),tm++);
+                    xastir_snprintf(ttemp, sizeof(ttemp), langcode("BBARSTA031"), tm++);
                     statusline(ttemp,1);        // Looking up hostname...
 
                     for (i=0; i < 60 && wait_host!=-1; i++) {
                         wait_host=waitpid(host_pid,&status,WNOHANG);
                         /* update display while waiting */
-                        XmUpdateDisplay(XtParent(da));
+//                        XmUpdateDisplay(XtParent(da));
                         //usleep(500);
                         sched_yield();
                     }
                 }
                 (void)read(fp[0],buf,sizeof(buf)-1);
                 strcpy(ip,buf);
+
+                if (debug_level & 1024)
+                    fprintf(stderr,"Parent closing read end of pipe\n");
+
+                close(fp[0]);   // Close the read end of the pipe
             }
         }
+        else {  // We didn't fork
+            // Close both ends of the pipe to make
+            // sure we've cleaned up properly
+            close(fp[0]);
+            close(fp[1]);
+        }
+    }
+    else {  // No pipe created
     }
     return(ip);
 }
 
+
