@@ -1,9 +1,9 @@
 /*
- * $Id: hostname.h,v 1.3 2001/05/01 14:33:43 kg4ijb Exp $
+ * $Id: hostname.h,v 1.3 2003/02/20 09:45:17 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000,2001  The Xastir Group
+ * Copyright (C) 2000-2003  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,4 +28,6 @@
 
 extern char *host_lookup(char *host, char *ip, int time);
 
-#endif
+#endif  // __XASTIR_HOSTNAME_H
+
+
