@@ -1,9 +1,9 @@
 /*
- * $Id: igate.h,v 1.3 2001/05/01 14:33:44 kg4ijb Exp $
+ * $Id: igate.h,v 1.4 2003/02/20 09:45:17 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000,2001  The Xastir Group
+ * Copyright (C) 2000-2003  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -30,9 +30,12 @@ typedef struct {
     char call[12];
 } NWS_Data;
 
-
+extern void igate_init(void);
+extern void insert_into_heard_queue(int port, char *line);
 extern void output_igate_net(char *line, int port, int third_party);
 extern void output_igate_rf(char *from, char *call, char *path, char *line, int port, int third_party);
 extern void output_nws_igate_rf(char *from, char *path, char *line, int port, int third_party);
 
-#endif
+#endif  // __XASTIR_IGATE_H
+
+
