@@ -1,9 +1,9 @@
 /*
- * $Id: lang.c,v 1.7 2001/05/01 14:33:44 kg4ijb Exp $
+ * $Id: lang.c,v 1.8 2003/05/20 17:34:10 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000,2001  The Xastir Group
+ * Copyright (C) 2000-2003  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,9 +22,8 @@
  * Look at the README for more information on the program.
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
+#include "snprintf.h"
 
 #include <stdio.h>
 #include <fcntl.h>
@@ -35,7 +34,17 @@
 #include <string.h>
 #include <ctype.h>
 #include <sys/types.h>
-#include <sys/time.h>
+
+#if TIME_WITH_SYS_TIME
+# include <sys/time.h>
+# include <time.h>
+#else   // TIME_WITH_SYS_TIME
+# if HAVE_SYS_TIME_H
+#  include <sys/time.h>
+# else  // HAVE_SYS_TIME_H
+#  include <time.h>
+# endif // HAVE_SYS_TIME_H
+#endif  // TIME_WITH_SYS_TIME
 
 #include <Xm/XmAll.h>
 
@@ -52,30 +61,68 @@ int lang_code_number;
 long buffer_len;
 char invalid_code[50];
 
+
+
+
+
 char *langcode(char *code) {
     int i;
-    sprintf(invalid_code,"IC>%s",code);
+
+    // Create an invalid code string to return in case we can't find the proper string
+    if (strlen(code) <= MAX_LANG_CODE) {    // Code is ok
+        xastir_snprintf(invalid_code, sizeof(invalid_code), "IC>%s", code);
+    }
+    else {  // Code is too long
+        xastir_snprintf(invalid_code, sizeof(invalid_code), "IC>TOO LONG:%s",code);
+        fprintf(stderr,"IC>TOO LONG:%s\n",code);
+        return(invalid_code);
+    }
+
     if(lang_code_number>0) {
         for(i=0;i<lang_code_number;i++) {
-            if(strcmp(code,lang_code[i])==0)
-                return(lang_code_ptr[i]);
+            if(strcmp(code,lang_code[i])==0) {  // Found a match
+                if (strlen(lang_code[i]) < MAX_LANG_LINE_SIZE) {
+                    return(lang_code_ptr[i]);   // Found it, length ok
+                }
+                else {
+                    fprintf(stderr,"String size: %d,  Max size: %d, %s\n",
+                        (int)strlen(lang_code[i]),
+                        MAX_LANG_LINE_SIZE,code);
+                    return(invalid_code);       // Found it, but string too long
+                }
+            }
         }
+        fprintf(stderr,"Language String not found:%s\n",code);
+        return(invalid_code);
     }
-    return(invalid_code);
+
+    fprintf(stderr,"No language strings loaded:%s\n",code);
+    return(invalid_code);   // No strings loaded in language file
 }
 
+
+
+
+
 char langcode_hotkey(char *code) {
     int i;
 
     if(lang_code_number>0) {
         for(i=0;i<lang_code_number;i++) {
-            if(strcmp(code,lang_code[i])==0)
-                return(lang_hotkey[i]);
+            if(strcmp(code,lang_code[i])==0) {
+                return(lang_hotkey[i]); // Found it
+            }
         }
     }
-    return(' ');
+
+    fprintf(stderr,"No hotkey for:%s\n",code);
+    return(' ');    // No strings loaded in language file
 }
 
+
+
+
+
 int load_language_file(char *filename) {
     FILE *f;
     char line[MAX_LANG_LINE_SIZE+1];
@@ -102,7 +149,7 @@ int load_language_file(char *filename) {
                         line[i]='\0';
                     } else {
                         ok=0;
-                        printf("Error! Line %d too long in language file\n",line_num);
+                        fprintf(stderr,"Error! Line %d too long in language file\n",line_num);
                     }
                 } else {
                     i=0;
@@ -132,42 +179,43 @@ int load_language_file(char *filename) {
                                                         temp_ptr=strtok(NULL,"|");      /* get hotkey */
                                                         if (temp_ptr!=NULL) {
                                                             lang_hotkey[lang_code_number]=temp_ptr[0];
-                                                            /*printf("HOTKEY %c\n",lang_hotkey[lang_code_number]);*/
+                                                            /*fprintf(stderr,"HOTKEY %c\n",lang_hotkey[lang_code_number]);*/
                                                         }
                                                     } else {
                                                         ok=0;
-                                                        printf("Language data buffer full error on line %d\n",line_num);
+                                                        fprintf(stderr,"Language data buffer full error on line %d\n",line_num);
                                                     }
                                                 } else {
                                                     ok=0;
-                                                    printf("Language string parse error on line %d\n",line_num);
+                                                    fprintf(stderr,"Language string parse error on line %d\n",line_num);
                                                 }
                                             } else {
                                                 ok=0;
-                                                printf("Duplicate code! <%s> on line %d\n",temp_ptr,line_num);
+                                                fprintf(stderr,"Duplicate code! <%s> on line %d\n",temp_ptr,line_num);
                                             }
                                         } else {
                                             ok=0;
-                                            printf("Language code on line %d is too long\n",line_num);
+                                            fprintf(stderr,"Language code on line %d is too long\n",line_num);
                                         }
                                     } else {
                                         ok=0;
-                                        printf("Missing Language code data on line %d\n",line_num);
+                                        fprintf(stderr,"Missing Language code data on line %d\n",line_num);
                                     }
                                 } else {
                                     ok=0;
-                                    printf("Language code parse error on line %d\n",line_num);
+                                    fprintf(stderr,"Language code parse error on line %d\n",line_num);
                                 }
                             } else {
                                 ok=0;
-                                printf("Language data buffer full error on line %d\n",line_num);
+                                fprintf(stderr,"Language data buffer full error on line %d\n",line_num);
                             }
                         } else {
                             ok=0;
-                            printf("Too many Language codes error on line %d\n",line_num);
+                            fprintf(stderr,"Too many Language codes error on line %d\n",line_num);
                         }
                         if (ok) {
-                            if (debug_level & 32) printf("Code #%d <%s> data <%s> hotkey <%c>\n",lang_code_number,
+                            if (debug_level & 32)
+                                fprintf(stderr,"Code #%d <%s> data <%s> hotkey <%c>\n",lang_code_number,
                                     lang_code[lang_code_number],lang_code_ptr[lang_code_number],
                                     lang_hotkey[lang_code_number]);
                                 lang_code_number++;
@@ -181,10 +229,12 @@ int load_language_file(char *filename) {
         (void)fclose(f);
     } else {
         ok=0;
-        printf("Could not read Language file: %s!\n",filename);
+        fprintf(stderr,"Could not read Language file: %s!\n",filename);
     }
     if (debug_level & 32)
-        printf("LANG %d\n",lang_code_number);
+        fprintf(stderr,"LANG %d\n",lang_code_number);
 
     return(ok);
 }
+
+
