@@ -1,9 +1,9 @@
 /*
- * $Id: list_gui.h,v 1.4 2001/05/01 14:33:44 kg4ijb Exp $
+ * $Id: list_gui.h,v 1.5 2003/02/20 09:45:17 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000,2001  The Xastir Group
+ * Copyright (C) 2000-2003  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -26,6 +26,16 @@
 #ifndef __XASTIR_LIST_GUI_H
 #define __XASTIR_LIST_GUI_H
 
+// different list types:
+#define LST_ALL 0
+#define LST_MOB 1
+#define LST_WX  2
+#define LST_TNC 3
+#define LST_TIM 4
+#define LST_OBJ 5
+#define LST_MYOBJ 6
+#define LST_NUM 7
+
 extern int list_size_h[];
 extern int list_size_w[];
 
@@ -33,5 +43,8 @@ extern int list_size_w[];
 extern void list_gui_init(void);
 extern void update_station_scroll_list(void);
 extern int stations_types(int type);
+extern void Station_List_fill(int type, int new_offset);
+
+#endif  // __XASTIR_LIST_GUI_H
+
 
-#endif
