@@ -1,9 +1,9 @@
 /*
- * $Id: location_gui.c,v 1.12 2001/05/01 14:33:44 kg4ijb Exp $
+ * $Id: location_gui.c,v 1.5 2003/04/16 23:42:19 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000,2001  The Xastir Group
+ * Copyright (C) 2000-2003  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,9 +22,7 @@
  * Look at the README for more information on the program.
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -46,6 +44,9 @@ Widget location_list;
 static xastir_mutex location_dialog_lock;
 
 
+
+
+
 void location_gui_init(void)
 {
     init_critical_section( &location_dialog_lock );
@@ -53,6 +54,8 @@ void location_gui_init(void)
 
 
 
+
+
 /************************************************/
 /* button fuction for last location             */
 /************************************************/
@@ -60,6 +63,10 @@ void Last_location(/*@unused@*/ Widget w, /*@unused@*/ XtPointer clientData, /*@
     map_pos_last_position();
 }
 
+
+
+
+
 /************************************************/
 /* manage jump locations                        */
 /************************************************/
@@ -76,6 +83,10 @@ end_critical_section(&location_dialog_lock, "location_gui.c:location_destroy_she
 
 }
 
+
+
+
+
 /************************************************/
 /* jump to chosen location/zoom                 */
 /************************************************/
@@ -117,7 +128,7 @@ void location_view(/*@unused@*/ Widget w, /*@unused@*/ XtPointer clientData, /*@
                         temp_ptr=strtok(NULL,"|");  /* get the pos */
                         strncpy(pos,temp_ptr,100);
                         if (strcmp(location,name)==0) {
-                            (void)sscanf(pos,"%s %s %s",s_lat,s_long,s_sz);
+                            (void)sscanf(pos,"%19s %19s %9s", s_lat, s_long, s_sz);
                             map_pos(convert_lat_s2l(s_lat),convert_lon_s2l(s_long),atol(s_sz));
                             done=1;
                         }
@@ -126,11 +137,17 @@ void location_view(/*@unused@*/ Widget w, /*@unused@*/ XtPointer clientData, /*@
             }
             (void)fclose(f);
         }
-        else
-            printf("Couldn't open file: %s\n", get_user_base_dir("config/locations.sys") );
+        else {
+            fprintf(stderr,"Couldn't open file: %s\n", get_user_base_dir("config/locations.sys") );
+        }
+        XtFree(location);
     }
 }
 
+
+
+
+
 /************************************************/
 /* sort and jump locations                      */
 /************************************************/
@@ -155,9 +172,13 @@ void jump_sort(void) {
         (void)fclose(f);
     }
     else
-        printf("Couldn't open file: %s\n", get_user_base_dir("config/locations.sys") );
+        fprintf(stderr,"Couldn't open file: %s\n", get_user_base_dir("config/locations.sys") );
 }
 
+
+
+
+
 /************************************************/
 /* delete location/zoom                         */
 /************************************************/
@@ -210,12 +231,14 @@ void location_delete(/*@unused@*/ Widget w, /*@unused@*/ XtPointer clientData, /
                 ok=1;
             }
             else
-                printf("Couldn't open file: %s\n", get_user_base_dir("config/locations.sys-tmp") );
+                fprintf(stderr,"Couldn't open file: %s\n", get_user_base_dir("config/locations.sys-tmp") );
 
             (void)fclose(f);
         }
-        else
-            printf("Couldn't open file: %s\n", get_user_base_dir("config/locations.sys") );
+        else {
+            fprintf(stderr,"Couldn't open file: %s\n", get_user_base_dir("config/locations.sys") );
+        }
+        XtFree(location);
     }
 
     if (ok==1){
@@ -228,6 +251,9 @@ void location_delete(/*@unused@*/ Widget w, /*@unused@*/ XtPointer clientData, /
 }
 
 
+
+
+
 /************************************************/
 /* add location/zoom                            */
 /************************************************/
@@ -261,7 +287,7 @@ void location_add(/*@unused@*/ Widget w, XtPointer clientData, /*@unused@*/ XtPo
         (void)fclose(f);
     }
     else
-        printf("Couldn't open file: %s\n", get_user_base_dir("config/locations.sys") );
+        fprintf(stderr,"Couldn't open file: %s\n", get_user_base_dir("config/locations.sys") );
 
     if (!found) {
         /* delete entire list available */
@@ -270,15 +296,15 @@ void location_add(/*@unused@*/ Widget w, XtPointer clientData, /*@unused@*/ XtPo
         if (len>0 && len<100){
             fout = fopen(get_user_base_dir("config/locations.sys"),"a");
             if (fout!=NULL) {
-                convert_lat_l2s(mid_y_lat_offset,s_lat,CONVERT_HP_NOSP);
+                convert_lat_l2s(mid_y_lat_offset, s_lat, sizeof(s_lat), CONVERT_HP_NOSP);
                 //strcpy(s_lat+2,s_lat+3);
-                convert_lon_l2s(mid_x_long_offset,s_long,CONVERT_HP_NOSP);
+                convert_lon_l2s(mid_x_long_offset, s_long, sizeof(s_long), CONVERT_HP_NOSP);
                 //strcpy(s_long+3,s_long+4);
-                fprintf(fout,"%s|%s %s %ld\n",name,s_lat,s_long,size);
+                fprintf(fout,"%s|%s %s %ld\n",name,s_lat,s_long,scale_y);
                 (void)fclose(fout);
             }
             else
-                printf("Couldn't open file: %s\n", get_user_base_dir("config/locations.sys") );
+                fprintf(stderr,"Couldn't open file: %s\n", get_user_base_dir("config/locations.sys") );
         } else
             popup_message(langcode("POPEM00022"),langcode("POPEM00023"));
 
@@ -292,6 +318,9 @@ void location_add(/*@unused@*/ Widget w, XtPointer clientData, /*@unused@*/ XtPo
 }
 
 
+
+
+
 /************************************************/
 /* manage jump locations                        */
 /************************************************/
@@ -306,28 +335,35 @@ void Jump_location(/*@unused@*/ Widget w, /*@unused@*/ XtPointer clientData, /*@
 
 begin_critical_section(&location_dialog_lock, "location_gui.c:Jump_location" );
 
-        location_dialog = XtVaCreatePopupShell(langcode("JMLPO00001"),xmDialogShellWidgetClass,appshell,
-                                  XmNdeleteResponse,XmDESTROY,
-                                  XmNdefaultPosition, FALSE,
-                                  XmNresize, FALSE,
-                                  NULL);
+        location_dialog = XtVaCreatePopupShell(langcode("JMLPO00001"),
+                xmDialogShellWidgetClass,
+                appshell,
+                XmNdeleteResponse,XmDESTROY,
+                XmNdefaultPosition, FALSE,
+                XmNresize, FALSE,
+                NULL);
 
-        pane = XtVaCreateWidget("pane",xmPanedWindowWidgetClass, location_dialog,
-                          XmNbackground, colors[0xff],
-                          NULL);
+        pane = XtVaCreateWidget("Jump_location pane",
+                xmPanedWindowWidgetClass,
+                location_dialog,
+                MY_FOREGROUND_COLOR,
+                MY_BACKGROUND_COLOR,
+                NULL);
 
-        form =  XtVaCreateWidget("form2",xmFormWidgetClass, pane,
-                            XmNfractionBase, 5,
-                            XmNbackground, colors[0xff],
-                            XmNautoUnmanage, FALSE,
-                            XmNshadowThickness, 1,
-                            NULL);
+        form =  XtVaCreateWidget("Jump_location form",
+                xmFormWidgetClass,
+                pane,
+                XmNfractionBase, 5,
+                XmNautoUnmanage, FALSE,
+                XmNshadowThickness, 1,
+                MY_FOREGROUND_COLOR,
+                MY_BACKGROUND_COLOR,
+                NULL);
 
         /*set args for color */
         ac=0;
-        XtSetArg(al[ac], XmNbackground, colors[0xff]); ac++;
         XtSetArg(al[ac], XmNvisibleItemCount, 11); ac++;
-        XtSetArg(al[ac], XmNtraversalOn, FALSE); ac++;
+        XtSetArg(al[ac], XmNtraversalOn, TRUE); ac++;
         XtSetArg(al[ac], XmNshadowThickness, 3); ac++;
         XtSetArg(al[ac], XmNbackground, colors[0x0ff]); ac++;
         XtSetArg(al[ac], XmNselectionPolicy, XmSINGLE_SELECT); ac++;
@@ -339,92 +375,114 @@ begin_critical_section(&location_dialog_lock, "location_gui.c:Jump_location" );
         XtSetArg(al[ac], XmNrightOffset, 5); ac++;
         XtSetArg(al[ac], XmNleftAttachment, XmATTACH_FORM); ac++;
         XtSetArg(al[ac], XmNleftOffset, 5); ac++;
-
-        location_list = XmCreateScrolledList(form,"list",al,ac);
+        XtSetArg(al[ac], XmNforeground, MY_FG_COLOR); ac++;
+        XtSetArg(al[ac], XmNbackground, MY_BG_COLOR); ac++;
+ 
+        location_list = XmCreateScrolledList(form,
+                "Jump_location list",
+                al,
+                ac);
 
         n=1;
         clear_sort_file(get_user_base_dir("data/locations_db.dat"));
         jump_sort();
         sort_list(get_user_base_dir("data/locations_db.dat"),200,location_list,&n);
 
-        locdata = XtVaCreateManagedWidget(langcode("JMLPO00003"),xmLabelWidgetClass, form,
-                                      XmNtopAttachment, XmATTACH_WIDGET,
-                                      XmNtopWidget, XtParent(location_list),
-                                      XmNtopOffset, 10,
-                                      XmNbottomAttachment, XmATTACH_NONE,
-                                      XmNleftAttachment, XmATTACH_FORM,
-                                      XmNleftOffset, 5,
-                                      XmNrightAttachment, XmATTACH_NONE,
-                                      XmNbackground, colors[0xff],
-                                      NULL);
+        locdata = XtVaCreateManagedWidget(langcode("JMLPO00003"),
+                xmLabelWidgetClass, 
+                form,
+                XmNtopAttachment, XmATTACH_WIDGET,
+                XmNtopWidget, XtParent(location_list),
+                XmNtopOffset, 10,
+                XmNbottomAttachment, XmATTACH_NONE,
+                XmNleftAttachment, XmATTACH_FORM,
+                XmNleftOffset, 5,
+                XmNrightAttachment, XmATTACH_NONE,
+                MY_FOREGROUND_COLOR,
+                MY_BACKGROUND_COLOR,
+                NULL);
 
-        location_name = XtVaCreateManagedWidget("Location_name", xmTextFieldWidgetClass, form,
-                                       XmNeditable,   TRUE,
-                                       XmNcursorPositionVisible, TRUE,
-                                       XmNsensitive, TRUE,
-                                       XmNshadowThickness,      1,
-                                       XmNcolumns,21,
-                                       XmNwidth,((21*7)+2),
-                                       XmNbackground, colors[0x0f],
-                                       XmNtopAttachment,XmATTACH_WIDGET,
-                                       XmNtopWidget, XtParent(location_list),
-                                       XmNtopOffset, 5,
-                                       XmNbottomAttachment,XmATTACH_NONE,
-                                       XmNleftAttachment, XmATTACH_WIDGET,
-                                       XmNleftWidget,locdata,
-                                       XmNrightAttachment,XmATTACH_FORM,
-                                       XmNrightOffset, 5,
-                                       NULL);
+        location_name = XtVaCreateManagedWidget("Jump_location Location_name", 
+                xmTextFieldWidgetClass, 
+                form,
+                XmNeditable,   TRUE,
+                XmNcursorPositionVisible, TRUE,
+                XmNsensitive, TRUE,
+                XmNshadowThickness,      1,
+                XmNcolumns,21,
+                XmNwidth,((21*7)+2),
+                XmNbackground, colors[0x0f],
+                XmNtopAttachment,XmATTACH_WIDGET,
+                XmNtopWidget, XtParent(location_list),
+                XmNtopOffset, 5,
+                XmNbottomAttachment,XmATTACH_NONE,
+                XmNleftAttachment, XmATTACH_WIDGET,
+                XmNleftWidget,locdata,
+                XmNrightAttachment,XmATTACH_FORM,
+                XmNrightOffset, 5,
+                NULL);
 
-        button_ok = XtVaCreateManagedWidget(langcode("JMLPO00002"),xmPushButtonGadgetClass, form,
-                                      XmNtopAttachment, XmATTACH_WIDGET,
-                                      XmNtopWidget, locdata,
-                                      XmNtopOffset,15,
-                                      XmNbottomAttachment, XmATTACH_FORM,
-                                      XmNbottomOffset,5,
-                                      XmNleftAttachment, XmATTACH_POSITION,
-                                      XmNleftPosition, 0,
-                                      XmNleftOffset, 3,
-                                      XmNrightAttachment, XmATTACH_POSITION,
-                                      XmNrightPosition, 1,
-                                      NULL);
+        button_ok = XtVaCreateManagedWidget(langcode("JMLPO00002"),
+                xmPushButtonGadgetClass, 
+                form,
+                XmNtopAttachment, XmATTACH_WIDGET,
+                XmNtopWidget, locdata,
+                XmNtopOffset,15,
+                XmNbottomAttachment, XmATTACH_FORM,
+                XmNbottomOffset,5,
+                XmNleftAttachment, XmATTACH_POSITION,
+                XmNleftPosition, 0,
+                XmNleftOffset, 3,
+                XmNrightAttachment, XmATTACH_POSITION,
+                XmNrightPosition, 1,
+                XmNnavigationType, XmTAB_GROUP,
+                NULL);
 
-        button_add = XtVaCreateManagedWidget(langcode("UNIOP00007"),xmPushButtonGadgetClass, form,
-                                      XmNtopAttachment, XmATTACH_WIDGET,
-                                      XmNtopWidget, locdata,
-                                      XmNtopOffset,15,
-                                      XmNbottomAttachment, XmATTACH_FORM,
-                                      XmNbottomOffset,5,
-                                      XmNleftAttachment, XmATTACH_POSITION,
-                                      XmNleftPosition, 1,
-                                      XmNrightAttachment, XmATTACH_POSITION,
-                                      XmNrightPosition, 2,
-                                      NULL);
+        button_add = XtVaCreateManagedWidget(langcode("UNIOP00007"),
+                xmPushButtonGadgetClass, 
+                form,
+                XmNtopAttachment, XmATTACH_WIDGET,
+                XmNtopWidget, locdata,
+                XmNtopOffset,15,
+                XmNbottomAttachment, XmATTACH_FORM,
+                XmNbottomOffset,5,
+                XmNleftAttachment, XmATTACH_POSITION,
+                XmNleftPosition, 1,
+                XmNrightAttachment, XmATTACH_POSITION,
+                XmNrightPosition, 2,
+                XmNnavigationType, XmTAB_GROUP,
+                NULL);
 
-        button_delete = XtVaCreateManagedWidget(langcode("UNIOP00008"),xmPushButtonGadgetClass, form,
-                                      XmNtopAttachment, XmATTACH_WIDGET,
-                                      XmNtopWidget, locdata,
-                                      XmNtopOffset,15,
-                                      XmNbottomAttachment, XmATTACH_FORM,
-                                      XmNbottomOffset,5,
-                                      XmNleftAttachment, XmATTACH_POSITION,
-                                      XmNleftPosition, 2,
-                                      XmNrightAttachment, XmATTACH_POSITION,
-                                      XmNrightPosition, 3,
-                                      NULL);
+        button_delete = XtVaCreateManagedWidget(langcode("UNIOP00008"),
+                xmPushButtonGadgetClass, 
+                form,
+                XmNtopAttachment, XmATTACH_WIDGET,
+                XmNtopWidget, locdata,
+                XmNtopOffset,15,
+                XmNbottomAttachment, XmATTACH_FORM,
+                XmNbottomOffset,5,
+                XmNleftAttachment, XmATTACH_POSITION,
+                XmNleftPosition, 2,
+                XmNrightAttachment, XmATTACH_POSITION,
+                XmNrightPosition, 3,
+                XmNnavigationType, XmTAB_GROUP,
+                NULL);
 
-        button_cancel = XtVaCreateManagedWidget(langcode("UNIOP00003"),xmPushButtonGadgetClass, form,
-                                      XmNtopAttachment, XmATTACH_WIDGET,
-                                      XmNtopWidget, locdata,
-                                      XmNtopOffset,15,
-                                      XmNbottomAttachment, XmATTACH_FORM,
-                                      XmNbottomOffset,5,
-                                      XmNleftAttachment, XmATTACH_POSITION,
-                                      XmNleftPosition, 4,
-                                      XmNrightAttachment, XmATTACH_POSITION,
-                                      XmNrightPosition, 5,
-                                      XmNrightOffset, 3,
-                                      NULL);
+        button_cancel = XtVaCreateManagedWidget(langcode("UNIOP00003"),
+                xmPushButtonGadgetClass, 
+                form,
+                XmNtopAttachment, XmATTACH_WIDGET,
+                XmNtopWidget, locdata,
+                XmNtopOffset,15,
+                XmNbottomAttachment, XmATTACH_FORM,
+                XmNbottomOffset,5,
+                XmNleftAttachment, XmATTACH_POSITION,
+                XmNleftPosition, 4,
+                XmNrightAttachment, XmATTACH_POSITION,
+                XmNrightPosition, 5,
+                XmNrightOffset, 3,
+                XmNnavigationType, XmTAB_GROUP,
+                NULL);
 
         XtAddCallback(button_cancel, XmNactivateCallback, location_destroy_shell, location_dialog);
         XtAddCallback(button_ok, XmNactivateCallback, location_view, NULL);
@@ -445,9 +503,18 @@ end_critical_section(&location_dialog_lock, "location_gui.c:location_destroy_she
 
         XtPopup(location_dialog,XtGrabNone);
         fix_dialog_size(location_dialog);
+
+        // Move focus to the Close button.  This appears to highlight the
+        // button fine, but we're not able to hit the <Enter> key to
+        // have that default function happen.  Note:  We _can_ hit the
+        // <SPACE> key, and that activates the option.
+//        XmUpdateDisplay(location_dialog);
+        XmProcessTraversal(button_cancel, XmTRAVERSE_CURRENT);
+
     } else {
         XtPopup(location_dialog,XtGrabNone);
         (void)XRaiseWindow(XtDisplay(location_dialog), XtWindow(location_dialog));
     }
 }
 
+
