@@ -1,9 +1,9 @@
 /*
- * $Id: popup_gui.c,v 1.8 2001/05/01 14:33:45 kg4ijb Exp $
+ * $Id: popup_gui.c,v 1.12 2003/06/06 23:57:17 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000,2001  The Xastir Group
+ * Copyright (C) 2000-2003  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -24,10 +24,11 @@
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
+#endif  // HAVE_CONFIG_H
 
 #include <stdlib.h>
 #include <stdio.h>
+#include <unistd.h>
 
 #include <Xm/XmAll.h>
 
@@ -36,14 +37,19 @@
 #include "popup.h"
 #include "main.h"
 #include "lang.h"
+#include "rotated.h"
+#include "snprintf.h"
 
 
 static Popup_Window pw[MAX_POPUPS];
+static Popup_Window pwb;
 
 static xastir_mutex popup_message_dialog_lock;
 
 
 
+
+
 void popup_gui_init(void)
 {
     init_critical_section( &popup_message_dialog_lock );
@@ -51,6 +57,8 @@ void popup_gui_init(void)
 
 
 
+
+
 /**** Popup Message ******/
 
 void clear_popup_message_windows(void) {
@@ -65,10 +73,14 @@ begin_critical_section(&popup_message_dialog_lock, "popup_gui.c:clear_popup_mess
 
 end_critical_section(&popup_message_dialog_lock, "popup_gui.c:clear_popup_message_windows" );
 
+    pwb.popup_message_dialog=(Widget)NULL;
+    pwb.popup_message_data=(Widget)NULL;
 }
 
 
 
+
+
 static void popup_message_destroy_shell(/*@unused@*/ Widget w,
                                 XtPointer clientData,
                                 /*@unused@*/ XtPointer callData) {
@@ -89,6 +101,8 @@ end_critical_section(&popup_message_dialog_lock, "popup_gui.c:popup_message_dest
 
 
 
+
+
 void popup_time_out_check(void) {
     int i;
 
@@ -110,6 +124,10 @@ end_critical_section(&popup_message_dialog_lock, "popup_gui.c:popup_time_out_che
     }
 }
 
+
+
+
+
 void popup_message(char *banner, char *message) {
     XmString msg_str;
     int j,i;
@@ -134,18 +152,18 @@ begin_critical_section(&popup_message_dialog_lock, "popup_gui.c:popup_message" )
                                   XmNtitleString,banner,
                                   NULL);
 
-            pw[i].pane = XtVaCreateWidget("pane",xmPanedWindowWidgetClass, pw[i].popup_message_dialog,
+            pw[i].pane = XtVaCreateWidget("popup_message pane",xmPanedWindowWidgetClass, pw[i].popup_message_dialog,
                           XmNbackground, colors[0xff],
                           NULL);
 
-            pw[i].form =  XtVaCreateWidget("form",xmFormWidgetClass, pw[i].pane,
+            pw[i].form =  XtVaCreateWidget("popup_message form",xmFormWidgetClass, pw[i].pane,
                             XmNfractionBase, 5,
                             XmNbackground, colors[0xff],
                             XmNautoUnmanage, FALSE,
                             XmNshadowThickness, 1,
                             NULL);
 
-            pw[i].popup_message_data = XtVaCreateManagedWidget("message",xmLabelWidgetClass, pw[i].form,
+            pw[i].popup_message_data = XtVaCreateManagedWidget("popup_message message",xmLabelWidgetClass, pw[i].form,
                                       XmNtopAttachment, XmATTACH_FORM,
                                       XmNtopOffset, 10,
                                       XmNbottomAttachment, XmATTACH_NONE,
@@ -195,3 +213,98 @@ end_critical_section(&popup_message_dialog_lock, "popup_gui.c:popup_message" );
     }
 }
 
+
+
+
+
+// Must make sure that fonts are not loaded again and again, as this
+// takes a big chunk of memory each time.  Can you say "memory
+// leak"?
+//
+static XFontStruct *id_font=NULL;
+char *id_fontname=
+    //"-adobe-helvetica-medium-o-normal--24-240-75-75-p-130-iso8859-1";
+    //"-adobe-helvetica-medium-o-normal--12-120-75-75-p-67-iso8859-1";
+    //"-adobe-helvetica-medium-r-*-*-*-130-*-*-*-*-*-*";
+    //"-*-times-bold-r-*-*-13-*-*-*-*-80-*-*";
+    //"-*-helvetica-bold-r-*-*-14-*-*-*-*-80-*-*";
+    //"-*-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*";
+    //"-*-helvetica-*-*-*-*-*-240-100-100-*-*-*-*";
+    "-*-helvetica-*-*-*-*-*-240-*-*-*-*-*-*";
+    //"-*-fixed-*-r-*-*-*-*-*-*-*-200-*-*";
+    //"-*-helvetica-bold-r-*-*-12-240-1075-1075-*-80-*-*";    // Test for bad font
+
+
+
+
+ 
+// Routine which pops up a large message for a few seconds in the
+// middle of the screen, then removes it.
+//
+void popup_ID_message(char *banner, char *message) {
+    float my_rotation = 0.0;
+    int x = (int)(screen_width/10);
+    int y = (int)(screen_height/2);
+
+    if (ATV_screen_ID) {
+
+        // Fill the pixmap with grey so that the black ID text will
+        // be seen.
+        (void)XSetForeground(XtDisplay(da),gc,MY_BG_COLOR); // Not a mistake!
+        (void)XSetBackground(XtDisplay(da),gc,MY_BG_COLOR);
+        (void)XFillRectangle(XtDisplay(appshell),pixmap_alerts,gc,0,0,screen_width,screen_height);
+
+        /* load font */
+        if(!id_font) {
+            id_font=(XFontStruct *)XLoadQueryFont (XtDisplay(da), id_fontname);
+            if (id_font == NULL) {    // Couldn't get the font!!!
+                fprintf(stderr,"popup_ID_message: Couldn't get font %s\n",
+                    id_fontname);
+                pending_ID_message = 0;
+                return;
+            }
+        }
+ 
+        (void)XSetForeground (XtDisplay(da), gc, colors[0x08]);
+
+        //fprintf(stderr,"%0.1f\t%s\n",my_rotation,label_text);
+
+        if (       ( (my_rotation < -90.0) && (my_rotation > -270.0) )
+                || ( (my_rotation >  90.0) && (my_rotation <  270.0) ) ) {
+            my_rotation = my_rotation + 180.0;
+            (void)XRotDrawAlignedString(XtDisplay(da),
+                id_font,
+                my_rotation,
+                pixmap_alerts,
+                gc,
+                x,
+                y,
+                message,
+                BRIGHT);
+        }
+        else {
+            (void)XRotDrawAlignedString(XtDisplay(da),
+                id_font,
+                my_rotation,
+                pixmap_alerts,
+                gc,
+                x,
+                y,
+                message,
+                BLEFT);
+        }
+
+        // Schedule a screen update in roughly 3 seconds
+        remove_ID_message_time = sec_now() + 3;
+        pending_ID_message = 1;
+
+        // Write it to the screen.  Symbols/tracks will disappear during
+        // this short interval time.
+        (void)XCopyArea(XtDisplay(da),pixmap_alerts,XtWindow(da),gc,0,0,screen_width,screen_height,0,0);
+    }
+    else {  // ATV Screen ID is not enabled
+        pending_ID_message = 0;
+    }
+}
+
+
