@@ -1,9 +1,9 @@
 /*
- * $Id: sound.c,v 1.6 2001/05/01 14:33:45 kg4ijb Exp $
+ * $Id: sound.c,v 1.4 2003/02/22 00:58:42 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000,2001  The Xastir Group
+ * Copyright (C) 2000-2003  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,9 +22,8 @@
  * Look at the README for more information on the program.
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
+#include "snprintf.h"
 
 #include <sys/types.h>
 #include <sys/wait.h>
@@ -36,6 +35,7 @@
 #include "main.h"
 
 
+
 pid_t play_sound(char *sound_cmd, char *soundfile) {
     pid_t sound_pid;
     char command[600];
@@ -50,22 +50,26 @@ pid_t play_sound(char *sound_cmd, char *soundfile) {
                     strcpy(file,SOUND_DIR);
                     strcat(file,"/");
                     strcat(file,soundfile);
-                    sprintf(command,"%s %s",sound_cmd,file);
-                    /*printf("PS%d:%s\n",sound_pid,file);*/
+                    xastir_snprintf(command, sizeof(command), "%s %s", sound_cmd, file);
+                    /*fprintf(stderr,"PS%d:%s\n",sound_pid,file);*/
                     (void)system(command);  // Note we're not caring about whether it succeeded or not
                     exit(0);
                 } else
                     last_sound_pid=sound_pid;
             } else
-                printf("Error! trying to play sound\n");
+                fprintf(stderr,"Error! trying to play sound\n");
         } else {
             sound_pid=last_sound_pid;
-            /*printf("Sound already running\n");*/
+            /*fprintf(stderr,"Sound already running\n");*/
         }
     }
     return(sound_pid);
 }
 
+
+
+
+
 int sound_done(void) {
     int done;
     int *status;
@@ -81,3 +85,4 @@ int sound_done(void) {
     return(done);
 }
 
+
