@@ -1,9 +1,9 @@
 /*
- * $Id: track_gui.h,v 1.4 2001/05/01 14:33:46 kg4ijb Exp $
+ * $Id: track_gui.h,v 1.4 2003/02/20 09:45:20 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000,2001  The Xastir Group
+ * Copyright (C) 2000-2003  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -31,8 +31,12 @@
 extern void track_gui_init(void);
 extern void Track_station(Widget w, XtPointer clientData, XtPointer callData);
 extern int track_station_on;
+extern int track_me;
 extern int track_case;
 extern int track_match;
 extern char tracking_station_call[30];
+extern void Download_findu_trail(Widget w, XtPointer clientData, XtPointer callData);
+
+#endif  // __TRACK_GUI_H
+
 
-#endif
