@@ -1,9 +1,9 @@
 /*
- * $Id: xa_config.h,v 1.5 2001/05/01 14:33:47 kg4ijb Exp $
+ * $Id: xa_config.h,v 1.4 2003/01/24 00:34:51 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000,2001  The Xastir Group
+ * Copyright (C) 2000-2003  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -25,19 +25,8 @@
 
 #define MAX_VALUE 300
 
-#define XASTIR_USER_BASE "/usr/local/xastir"
-#define XASTIR_DATA_BASE "/usr/local/xastir"
-
 extern time_t next_time;
 
-void store_string(FILE *fout,char *option, char *value);
-void store_char(FILE *fout,char *option, char value);
-void store_int(FILE *fout,char *option, int value);
-void store_long(FILE *fout,char *option, long value);
-int get_string(char *option, char *value);
-int get_char(char *option, char *value);
-int get_int(char *option, int *value);
-int get_long(char *option, long *value);
 char *get_user_base_dir(char *dir);
 char *get_data_base_dir(char *dir);
 void save_data(void);
